wsipipe.load package
====================

.. automodule:: wsipipe.load
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   wsipipe.load.annotations
   wsipipe.load.datasets
   wsipipe.load.slides

